Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(252)

Unified Diff: webkit/dom_storage/session_storage_database.cc

Issue 13219005: Replace string16 with base::string16 in src/webkit (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/dom_storage/session_storage_database.cc
diff --git a/webkit/dom_storage/session_storage_database.cc b/webkit/dom_storage/session_storage_database.cc
index 2e873d727c48dedc749101372f30cafbca099d65..699221f2587eea60bf6b76644d491722786b6576 100644
--- a/webkit/dom_storage/session_storage_database.cc
+++ b/webkit/dom_storage/session_storage_database.cc
@@ -521,16 +521,16 @@ bool SessionStorageDatabase::ReadMap(const std::string& map_id,
break;
}
// Key is of the form "map-<mapid>-<key>".
- string16 key16 = UTF8ToUTF16(key.substr(map_start_key.length()));
+ base::string16 key16 = UTF8ToUTF16(key.substr(map_start_key.length()));
if (only_keys) {
(*result)[key16] = NullableString16(true);
} else {
// Convert the raw data stored in std::string (it->value()) to raw data
- // stored in string16.
+ // stored in base::string16.
size_t len = it->value().size() / sizeof(char16);
const char16* data_ptr =
reinterpret_cast<const char16*>(it->value().data());
- (*result)[key16] = NullableString16(string16(data_ptr, len), false);
+ (*result)[key16] = NullableString16(base::string16(data_ptr, len), false);
}
}
return true;
@@ -546,7 +546,7 @@ void SessionStorageDatabase::WriteValuesToMap(const std::string& map_id,
if (value.is_null()) {
batch->Delete(key);
} else {
// Convert the raw data stored in string16 to raw data stored in
// std::string.
const char* data = reinterpret_cast<const char*>(value.string().data());
size_t size = value.string().size() * 2;
@@ -546,7 +546,7 @@ void SessionStorageDatabase::WriteValuesToMap(const std::string& map_id,
batch->Delete(key);
} else {
- // Convert the raw data stored in string16 to raw data stored in
+ // Convert the raw data stored in base::string16 to raw data stored in
// std::string.
const char* data = reinterpret_cast<const char*>(value.string().data());

Powered by Google App Engine
This is Rietveld 408576698